"""
Tests for Vela Forger
"""
from unittest.mock import patch, mock_open
from vela.forger import read_metadata, VelaProduct, VelaLog


class TestVelaLog:
    @patch("os.chdir")
    @patch("pendulum.now")
    def test_forge_logs(self, mock_pendulum, mock_os):
        parameters = read_metadata("test/test.json")
        with patch("builtins.open", mock_open()) as o:
            VelaLog("test.json").forge_logs(parameters=parameters)
            o.call_count == 3
            handle = o()
            handle.write.call_count == 3


class TestVelaProduct:
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_weblog")
    def test_forge_cal_products(self, mock_forge, mock_os):
        parameters = read_metadata("test/test.json")
        with patch("builtins.open", mock_open()) as o:
            VelaProduct("test.json").forge_cal_products(parameters=parameters)
            o.assert_called_once_with("brain_001.58099.678886747686.ms.calapply.txt", "x")
            handle = o()
            handle.write.assert_called_once_with("I am a calibration file.")

    @patch("os.mkdir")
    @patch("os.chdir")
    @patch("pendulum.now")
    @patch("tarfile.open")
    def test_forge_weblog(self, mock_tar, mock_pendulum, mock_os_chdir, mock_os_mkdir):
        with patch("builtins.open", mock_open()) as o:
            VelaProduct("test.json").forge_weblog(path="/tmp/workspaces_tmp/testing")
            o.call_count == 3
            handle = o()
            handle.write.call_count == 3


def test_read_metadata():
    parameters = read_metadata("test/test.json")
    assert parameters["fileSetIds"] == "brain_001.58099.678886747686"
    assert parameters["workflowName"] == "std_calibration"
    assert parameters["systemId"] == "5"
    assert parameters["productLocator"] == "uid://evla/execblock/9cb0964b-ad6b-40ed-bd87-d08c502503e2"
    project = parameters.get("projectMetadata")
    assert project["projectCode"] == "Operations"
    assert project["title"] == ""
    assert project["startTime"] == "58099.6790081019"
    assert project["observer"] == "VLA Operations"

